[![Build Status](https://travis-ci.com/intellineers/django-bridger.svg?branch=master)](https://travis-ci.com/intellineers/django-bridger)
[![codecov](https://codecov.io/gh/intellineers/django-bridger/branch/master/graph/badge.svg)](https://codecov.io/gh/intellineers/django-bridger)

# Django Bridger
A django app, that bridges the gap between the backend and frontend to enable automatic creation of frontend apps.
